@@ -9,11 +9,12 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                        cmp_version
-                       version_eq
+                       version_eq version_ne
                        version_lt version_le version_gt version_ge
+                       version_between version_in
                );
 
-our $VERSION = '0.63'; # VERSION
+our $VERSION = '0.64'; # VERSION
 
 sub cmp_version {
     version->parse($_[0]) <=> version->parse($_[1]);
@@ -23,6 +24,10 @@ sub version_eq {
     version->parse($_[0]) == version->parse($_[1]);
 }
 
+sub version_ne {
+    version->parse($_[0]) != version->parse($_[1]);
+}
+
 sub version_lt {
     version->parse($_[0]) <  version->parse($_[1]);
 }
@@ -39,6 +44,24 @@ sub version_ge {
     version->parse($_[0]) >= version->parse($_[1]);
 }
 
+sub version_between {
+    my $v = version->parse(shift);
+    while (@_) {
+        my $v1 = shift;
+        my $v2 = shift;
+        return 1 if $v >= version->parse($v1) && $v <= version->parse($v2);
+    }
+    0;
+}
+
+sub version_in {
+    my $v = version->parse(shift);
+    for (@_) {
+        return 1 if $v == version->parse($_);
+    }
+    0;
+}
+
 1;
 # ABSTRACT: Version utilities
 
@@ -54,7 +77,7 @@ SHARYANTO::Version::Util - Version utilities
 
 =head1 VERSION
 
-version 0.63
+version 0.64
 
 =head1 FUNCTIONS
 
@@ -66,6 +89,8 @@ Equivalent to:
 
 =head2 version_eq($v1, $v2) => BOOL
 
+=head2 version_ne($v1, $v2) => BOOL
+
 =head2 version_lt($v1, $v2) => BOOL
 
 =head2 version_le($v1, $v2) => BOOL
@@ -74,6 +99,10 @@ Equivalent to:
 
 =head2 version_ge($v1, $v2) => BOOL
 
+=head2 version_between($v, $v1, $v2[, $v1b, $v2b, ...]) => BOOL
+
+=head2 version_in($v, $v1[, $v2, ...]) => BOOL
+
 =head1 SEE ALSO
 
 L<SHARYANTO>
